<?php

// Require json support
include_once('wfmjson.php');

// Only define the function if it doesn't already exist
if (!function_exists('wplocal')) {

	function wplocal($path = '', $mediabox = false) {
		
		// Get the real path
		$path = rtrim($path, "/") . "/";
		$folder = realpath($path);
		
		// The local photos
		$local = array();
		
		// Turn off error reporting
		$ini = error_reporting(0);
		
		// If we opened the directory
		if ($handle = opendir($folder)) {
			
			// Loop over each file in the directory. We are looking for images and txt files
			// The text files are read in and used as the caption for the image
			while (false !== ($file = readdir($handle))) {
				
				// Get the mime
				$src = $path.$file;
				$mime = getMimeType($src);
				
				// If the mime is an image type
				if (startsWith($mime, 'image/')) {
					
					// The description
					$desc = $file;
					
					// The href for the image
					$href = $src;
					
					// Look for a text file with the same name
					$desc_path = realpath($src.'.txt');
					
					// Try uppercase extensions just in case
					// the lowercase txt doesn't exist
					if (!file_exists($desc_path)) {
						$desc_path = realpath($src.'.TXT');
					}
					
					if (file_exists($desc_path)) {
						
						// Open the file description
						$filehandle = @fopen($desc_path, 'r');
						
						// If opened
						if ($filehandle) {
							
							// Take the first 1k of characters and make it the description
							$desc = fgets($filehandle);
						}
						
						// If there is more to the file
						if (!feof($filehandle) and !$mediabox) {
							
							// Use the 2nd line as the href
							$href = fgets($filehandle);
						}
						
						// Close the file
						fclose($filehandle);
					}
					
					$local[$src] = array('caption' => $desc, 'thumbnail' => $src, 'href' => $href);
					//error_log('src: '.$src.' caption: '.$desc.' thumbnail: '.$src.' href: '.$href);
				}
			}
		}
		
		// Reset error reporting
		error_reporting($ini);
		
		// Return a json encoded string
		return json_encode($local);
	}
}


// Only define the function if it doesn't already exist
if (!function_exists('getMimeType')) {
	function getMimeType($file){
		return is_dir($file) ? 'text/directory' : mime($file);
	}
}

// Only define the function if it doesn't already exist
if (!function_exists('mime')) {
	function mime($file, $options = array()){
	
		// Adding $mime declaration to avoid PHP warning
		$mime = '';
	
		// Below is implementation from filemananger 
		$file = realpath($file);
		$options = array_merge(array(
			'default' => null,
			'extension' => strtolower(pathinfo($file, PATHINFO_EXTENSION)),
		), $options);
	
		$ini = error_reporting(0);
		if (function_exists('finfo_open') && $f = finfo_open(FILEINFO_MIME, getenv('MAGIC'))){
			$mime = finfo_file($f, $file);
			finfo_close($f);
		}
		error_reporting($ini);
	
		if(!$mime && in_array($options['extension'], array('gif', 'jpg', 'jpeg', 'png'))){
			$image = getimagesize($file);
			if(!empty($image['mime']))
				$mime = $image['mime'];
		}
	
		if(!$mime && $options['default']) $mime = $options['default'];
	
		if((!$mime || $mime=='application/octet-stream') && $options['extension']){
			static $mimes;
			if(!$mimes) $mimes = parse_ini_file(pathinfo(__FILE__, PATHINFO_DIRNAME).'/MimeTypes.ini');
		
			if(!empty($mimes[$options['extension']])) return $mimes[$options['extension']];
		}
	
		return $mime;
	}
}

// For PHP 5.x support
// Author: Gregory Barchard
// February 23, 2010
// Based on work done at http://www.php.net/manual/en/function.pathinfo.php#88159
if (!function_exists('pathinfo_filename')) {
	function pathinfo_filename($file) { //file.name.ext, returns file.name

		// If the PATHINFO_FILENAME variable is defined, use it
	    if (defined('PATHINFO_FILENAME')) return pathinfo($file, PATHINFO_FILENAME);

		// Get the path info for the file
		$pathinfo = pathinfo($file);
	
		// Get the basename (filename.extension)
		$basename = $pathinfo['basename'];
	
		// Assume the filename to be the same as the basename
		$filename = $basename;
	
		// If an extension exists in the basename
	    if (strstr($basename, '.')) {
	
			// Split the filename off
			$filename = substr($basename, 0, strrpos($basename, '.'));
		}
	
		// Return the filename
		return $filename;
	}
}

if (!function_exists('startsWith')) {
	function startsWith($string, $look){
		return strpos($string, $look)===0;
	}
}

if (!function_exists('endsWith')) {
	function endsWith($string, $look){
		return strrpos($string, $look)===strlen($string)-strlen($look);
	}
}

?>